==> plantuml-libs-5.2.0.tgz: package/distribution/gcp/Item/IdentitySecurity/DataLossPreventionApi.md <==
# DataLossPreventionApi


```text
gcp/Item/IdentitySecurity/DataLossPreventionApi
```

```text
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')
```



| Illustration | DataLossPreventionApi | DataLossPreventionApiCard | DataLossPreventionApiGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../gcp/Item/IdentitySecurity/DataLossPreventionApi.png) | ![illustration for DataLossPreventionApi](../../../gcp/Item/IdentitySecurity/DataLossPreventionApi.Local.png) | ![illustration for DataLossPreventionApiCard](../../../gcp/Item/IdentitySecurity/DataLossPreventionApiCard.Local.png) | ![illustration for DataLossPreventionApiGroup](../../../gcp/Item/IdentitySecurity/DataLossPreventionApiGroup.Local.png) |




## DataLossPreventionApi

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApi
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApi('DataLossPreventionApi', 'Data Loss Prevention Api', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApi
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApi('DataLossPreventionApi', 'Data Loss Prevention Api', 'an optional tech label')
@enduml
```

## DataLossPreventionApiCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiCard
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiCard('DataLossPreventionApiCard', 'Data Loss Prevention Api Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiCard
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiCard('DataLossPreventionApiCard', 'Data Loss Prevention Api Card', 'an optional description')
@enduml
```

## DataLossPreventionApiGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiGroup
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiGroup('DataLossPreventionApiGroup', 'Data Loss Prevention Api Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiGroup
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiGroup('DataLossPreventionApiGroup', 'Data Loss Prevention Api Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.1.1.tgz: package/distribution/gcp/Item/IdentitySecurity/DataLossPreventionApi.md <==
# DataLossPreventionApi


```text
gcp/Item/IdentitySecurity/DataLossPreventionApi
```

```text
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')
```



| Illustration | DataLossPreventionApi | DataLossPreventionApiCard | DataLossPreventionApiGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../gcp/Item/IdentitySecurity/DataLossPreventionApi.png) | ![illustration for DataLossPreventionApi](../../../gcp/Item/IdentitySecurity/DataLossPreventionApi.Local.png) | ![illustration for DataLossPreventionApiCard](../../../gcp/Item/IdentitySecurity/DataLossPreventionApiCard.Local.png) | ![illustration for DataLossPreventionApiGroup](../../../gcp/Item/IdentitySecurity/DataLossPreventionApiGroup.Local.png) |




## DataLossPreventionApi

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApi
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApi('DataLossPreventionApi', 'Data Loss Prevention Api', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApi
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApi('DataLossPreventionApi', 'Data Loss Prevention Api', 'an optional tech label')
@enduml
```

## DataLossPreventionApiCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiCard
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiCard('DataLossPreventionApiCard', 'Data Loss Prevention Api Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiCard
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiCard('DataLossPreventionApiCard', 'Data Loss Prevention Api Card', 'an optional description')
@enduml
```

## DataLossPreventionApiGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiGroup
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiGroup('DataLossPreventionApiGroup', 'Data Loss Prevention Api Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('gcp/bootstrap')

' loads the Item which embeds the element DataLossPreventionApiGroup
include('gcp/Item/IdentitySecurity/DataLossPreventionApi')

' renders the element
DataLossPreventionApiGroup('DataLossPreventionApiGroup', 'Data Loss Prevention Api Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
